"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RegisterPublisherCommand = void 0;
const models_0_1 = require("../models/models_0");
const Aws_query_1 = require("../protocols/Aws_query");
const middleware_serde_1 = require("@aws-sdk/middleware-serde");
const smithy_client_1 = require("@aws-sdk/smithy-client");
/**
 * <p>Registers your account as a publisher of public extensions in the CloudFormation
 *          registry. Public extensions are available for use by all CloudFormation users. This
 *          publisher ID applies to your account in all Regions.</p>
 *          <p>For information on requirements for registering as a public extension publisher, see
 *             <a href="https://docs.aws.amazon.com/cloudformation-cli/latest/userguide/publish-extension.html#publish-extension-prereqs">Registering your account to publish CloudFormation
 *             extensions</a> in the <i>CloudFormation CLI User Guide</i>.</p>
 *          <p></p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { CloudFormationClient, RegisterPublisherCommand } from "@aws-sdk/client-cloudformation"; // ES Modules import
 * // const { CloudFormationClient, RegisterPublisherCommand } = require("@aws-sdk/client-cloudformation"); // CommonJS import
 * const client = new CloudFormationClient(config);
 * const command = new RegisterPublisherCommand(input);
 * const response = await client.send(command);
 * ```
 *
 * @see {@link RegisterPublisherCommandInput} for command's `input` shape.
 * @see {@link RegisterPublisherCommandOutput} for command's `response` shape.
 * @see {@link CloudFormationClientResolvedConfig | config} for command's `input` shape.
 *
 */
class RegisterPublisherCommand extends smithy_client_1.Command {
    // Start section: command_properties
    // End section: command_properties
    constructor(input) {
        // Start section: command_constructor
        super();
        this.input = input;
        // End section: command_constructor
    }
    /**
     * @internal
     */
    resolveMiddleware(clientStack, configuration, options) {
        this.middlewareStack.use(middleware_serde_1.getSerdePlugin(configuration, this.serialize, this.deserialize));
        const stack = clientStack.concat(this.middlewareStack);
        const { logger } = configuration;
        const clientName = "CloudFormationClient";
        const commandName = "RegisterPublisherCommand";
        const handlerExecutionContext = {
            logger,
            clientName,
            commandName,
            inputFilterSensitiveLog: models_0_1.RegisterPublisherInput.filterSensitiveLog,
            outputFilterSensitiveLog: models_0_1.RegisterPublisherOutput.filterSensitiveLog,
        };
        const { requestHandler } = configuration;
        return stack.resolve((request) => requestHandler.handle(request.request, options || {}), handlerExecutionContext);
    }
    serialize(input, context) {
        return Aws_query_1.serializeAws_queryRegisterPublisherCommand(input, context);
    }
    deserialize(output, context) {
        return Aws_query_1.deserializeAws_queryRegisterPublisherCommand(output, context);
    }
}
exports.RegisterPublisherCommand = RegisterPublisherCommand;
//# sourceMappingURL=RegisterPublisherCommand.js.map