import { __extends } from "tslib";
import { DescribePublisherInput, DescribePublisherOutput } from "../models/models_0";
import { deserializeAws_queryDescribePublisherCommand, serializeAws_queryDescribePublisherCommand, } from "../protocols/Aws_query";
import { getSerdePlugin } from "@aws-sdk/middleware-serde";
import { Command as $Command } from "@aws-sdk/smithy-client";
/**
 * <p>Returns information about a CloudFormation extension publisher.</p>
 *          <p>If you do not supply a <code>PublisherId</code>, and you have registered as an extension
 *          publisher, <code>DescribePublisher</code> returns information about your own publisher
 *          account. </p>
 *          <p>For more information on registering as a publisher, see:</p>
 *          <ul>
 *             <li>
 *                <p>
 *                   <a href="https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_RegisterPublisher.html">RegisterPublisher</a>
 *                </p>
 *             </li>
 *             <li>
 *                <p>
 *                   <a href="https://docs.aws.amazon.com/cloudformation-cli/latest/userguide/publish-extension.html">Publishing
 *                   extensions to make them available for public use</a> in the
 *                   <i>CloudFormation CLI User Guide</i>
 *                </p>
 *             </li>
 *          </ul>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { CloudFormationClient, DescribePublisherCommand } from "@aws-sdk/client-cloudformation"; // ES Modules import
 * // const { CloudFormationClient, DescribePublisherCommand } = require("@aws-sdk/client-cloudformation"); // CommonJS import
 * const client = new CloudFormationClient(config);
 * const command = new DescribePublisherCommand(input);
 * const response = await client.send(command);
 * ```
 *
 * @see {@link DescribePublisherCommandInput} for command's `input` shape.
 * @see {@link DescribePublisherCommandOutput} for command's `response` shape.
 * @see {@link CloudFormationClientResolvedConfig | config} for command's `input` shape.
 *
 */
var DescribePublisherCommand = /** @class */ (function (_super) {
    __extends(DescribePublisherCommand, _super);
    // Start section: command_properties
    // End section: command_properties
    function DescribePublisherCommand(input) {
        var _this = 
        // Start section: command_constructor
        _super.call(this) || this;
        _this.input = input;
        return _this;
        // End section: command_constructor
    }
    /**
     * @internal
     */
    DescribePublisherCommand.prototype.resolveMiddleware = function (clientStack, configuration, options) {
        this.middlewareStack.use(getSerdePlugin(configuration, this.serialize, this.deserialize));
        var stack = clientStack.concat(this.middlewareStack);
        var logger = configuration.logger;
        var clientName = "CloudFormationClient";
        var commandName = "DescribePublisherCommand";
        var handlerExecutionContext = {
            logger: logger,
            clientName: clientName,
            commandName: commandName,
            inputFilterSensitiveLog: DescribePublisherInput.filterSensitiveLog,
            outputFilterSensitiveLog: DescribePublisherOutput.filterSensitiveLog,
        };
        var requestHandler = configuration.requestHandler;
        return stack.resolve(function (request) {
            return requestHandler.handle(request.request, options || {});
        }, handlerExecutionContext);
    };
    DescribePublisherCommand.prototype.serialize = function (input, context) {
        return serializeAws_queryDescribePublisherCommand(input, context);
    };
    DescribePublisherCommand.prototype.deserialize = function (output, context) {
        return deserializeAws_queryDescribePublisherCommand(output, context);
    };
    return DescribePublisherCommand;
}($Command));
export { DescribePublisherCommand };
//# sourceMappingURL=DescribePublisherCommand.js.map