import { __extends } from "tslib";
import { ImportStacksToStackSetInput, ImportStacksToStackSetOutput } from "../models/models_0";
import { deserializeAws_queryImportStacksToStackSetCommand, serializeAws_queryImportStacksToStackSetCommand, } from "../protocols/Aws_query";
import { getSerdePlugin } from "@aws-sdk/middleware-serde";
import { Command as $Command } from "@aws-sdk/smithy-client";
/**
 * <p>Import existing stacks into a new stack sets. Use the stack import operation to import
 *          up to 10 stacks into a new stack set in the same account as the source stack or in a
 *          different administrator account and Region, by specifying the stack ID of the stack you
 *          intend to import.</p>
 *          <note>
 *             <p>
 *                <code>ImportStacksToStackSet</code> is only supported by self-managed permissions.</p>
 *          </note>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { CloudFormationClient, ImportStacksToStackSetCommand } from "@aws-sdk/client-cloudformation"; // ES Modules import
 * // const { CloudFormationClient, ImportStacksToStackSetCommand } = require("@aws-sdk/client-cloudformation"); // CommonJS import
 * const client = new CloudFormationClient(config);
 * const command = new ImportStacksToStackSetCommand(input);
 * const response = await client.send(command);
 * ```
 *
 * @see {@link ImportStacksToStackSetCommandInput} for command's `input` shape.
 * @see {@link ImportStacksToStackSetCommandOutput} for command's `response` shape.
 * @see {@link CloudFormationClientResolvedConfig | config} for command's `input` shape.
 *
 */
var ImportStacksToStackSetCommand = /** @class */ (function (_super) {
    __extends(ImportStacksToStackSetCommand, _super);
    // Start section: command_properties
    // End section: command_properties
    function ImportStacksToStackSetCommand(input) {
        var _this = 
        // Start section: command_constructor
        _super.call(this) || this;
        _this.input = input;
        return _this;
        // End section: command_constructor
    }
    /**
     * @internal
     */
    ImportStacksToStackSetCommand.prototype.resolveMiddleware = function (clientStack, configuration, options) {
        this.middlewareStack.use(getSerdePlugin(configuration, this.serialize, this.deserialize));
        var stack = clientStack.concat(this.middlewareStack);
        var logger = configuration.logger;
        var clientName = "CloudFormationClient";
        var commandName = "ImportStacksToStackSetCommand";
        var handlerExecutionContext = {
            logger: logger,
            clientName: clientName,
            commandName: commandName,
            inputFilterSensitiveLog: ImportStacksToStackSetInput.filterSensitiveLog,
            outputFilterSensitiveLog: ImportStacksToStackSetOutput.filterSensitiveLog,
        };
        var requestHandler = configuration.requestHandler;
        return stack.resolve(function (request) {
            return requestHandler.handle(request.request, options || {});
        }, handlerExecutionContext);
    };
    ImportStacksToStackSetCommand.prototype.serialize = function (input, context) {
        return serializeAws_queryImportStacksToStackSetCommand(input, context);
    };
    ImportStacksToStackSetCommand.prototype.deserialize = function (output, context) {
        return deserializeAws_queryImportStacksToStackSetCommand(output, context);
    };
    return ImportStacksToStackSetCommand;
}($Command));
export { ImportStacksToStackSetCommand };
//# sourceMappingURL=ImportStacksToStackSetCommand.js.map