import { __extends } from "tslib";
import { PublishTypeInput, PublishTypeOutput } from "../models/models_0";
import { deserializeAws_queryPublishTypeCommand, serializeAws_queryPublishTypeCommand } from "../protocols/Aws_query";
import { getSerdePlugin } from "@aws-sdk/middleware-serde";
import { Command as $Command } from "@aws-sdk/smithy-client";
/**
 * <p>Publishes the specified extension to the CloudFormation registry as a public extension
 *          in this region. Public extensions are available for use by all CloudFormation users. For
 *          more information on publishing extensions, see <a href="https://docs.aws.amazon.com/cloudformation-cli/latest/userguide/publish-extension.html">Publishing extensions to make them available for public use</a> in the
 *             <i>CloudFormation CLI User Guide</i>.</p>
 *          <p>To publish an extension, you must be registered as a publisher with CloudFormation. For
 *          more information, see <a href="https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_RegisterPublisher.html">RegisterPublisher</a>.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { CloudFormationClient, PublishTypeCommand } from "@aws-sdk/client-cloudformation"; // ES Modules import
 * // const { CloudFormationClient, PublishTypeCommand } = require("@aws-sdk/client-cloudformation"); // CommonJS import
 * const client = new CloudFormationClient(config);
 * const command = new PublishTypeCommand(input);
 * const response = await client.send(command);
 * ```
 *
 * @see {@link PublishTypeCommandInput} for command's `input` shape.
 * @see {@link PublishTypeCommandOutput} for command's `response` shape.
 * @see {@link CloudFormationClientResolvedConfig | config} for command's `input` shape.
 *
 */
var PublishTypeCommand = /** @class */ (function (_super) {
    __extends(PublishTypeCommand, _super);
    // Start section: command_properties
    // End section: command_properties
    function PublishTypeCommand(input) {
        var _this = 
        // Start section: command_constructor
        _super.call(this) || this;
        _this.input = input;
        return _this;
        // End section: command_constructor
    }
    /**
     * @internal
     */
    PublishTypeCommand.prototype.resolveMiddleware = function (clientStack, configuration, options) {
        this.middlewareStack.use(getSerdePlugin(configuration, this.serialize, this.deserialize));
        var stack = clientStack.concat(this.middlewareStack);
        var logger = configuration.logger;
        var clientName = "CloudFormationClient";
        var commandName = "PublishTypeCommand";
        var handlerExecutionContext = {
            logger: logger,
            clientName: clientName,
            commandName: commandName,
            inputFilterSensitiveLog: PublishTypeInput.filterSensitiveLog,
            outputFilterSensitiveLog: PublishTypeOutput.filterSensitiveLog,
        };
        var requestHandler = configuration.requestHandler;
        return stack.resolve(function (request) {
            return requestHandler.handle(request.request, options || {});
        }, handlerExecutionContext);
    };
    PublishTypeCommand.prototype.serialize = function (input, context) {
        return serializeAws_queryPublishTypeCommand(input, context);
    };
    PublishTypeCommand.prototype.deserialize = function (output, context) {
        return deserializeAws_queryPublishTypeCommand(output, context);
    };
    return PublishTypeCommand;
}($Command));
export { PublishTypeCommand };
//# sourceMappingURL=PublishTypeCommand.js.map