import { __extends } from "tslib";
import { RegisterPublisherInput, RegisterPublisherOutput } from "../models/models_0";
import { deserializeAws_queryRegisterPublisherCommand, serializeAws_queryRegisterPublisherCommand, } from "../protocols/Aws_query";
import { getSerdePlugin } from "@aws-sdk/middleware-serde";
import { Command as $Command } from "@aws-sdk/smithy-client";
/**
 * <p>Registers your account as a publisher of public extensions in the CloudFormation
 *          registry. Public extensions are available for use by all CloudFormation users. This
 *          publisher ID applies to your account in all Regions.</p>
 *          <p>For information on requirements for registering as a public extension publisher, see
 *             <a href="https://docs.aws.amazon.com/cloudformation-cli/latest/userguide/publish-extension.html#publish-extension-prereqs">Registering your account to publish CloudFormation
 *             extensions</a> in the <i>CloudFormation CLI User Guide</i>.</p>
 *          <p></p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { CloudFormationClient, RegisterPublisherCommand } from "@aws-sdk/client-cloudformation"; // ES Modules import
 * // const { CloudFormationClient, RegisterPublisherCommand } = require("@aws-sdk/client-cloudformation"); // CommonJS import
 * const client = new CloudFormationClient(config);
 * const command = new RegisterPublisherCommand(input);
 * const response = await client.send(command);
 * ```
 *
 * @see {@link RegisterPublisherCommandInput} for command's `input` shape.
 * @see {@link RegisterPublisherCommandOutput} for command's `response` shape.
 * @see {@link CloudFormationClientResolvedConfig | config} for command's `input` shape.
 *
 */
var RegisterPublisherCommand = /** @class */ (function (_super) {
    __extends(RegisterPublisherCommand, _super);
    // Start section: command_properties
    // End section: command_properties
    function RegisterPublisherCommand(input) {
        var _this = 
        // Start section: command_constructor
        _super.call(this) || this;
        _this.input = input;
        return _this;
        // End section: command_constructor
    }
    /**
     * @internal
     */
    RegisterPublisherCommand.prototype.resolveMiddleware = function (clientStack, configuration, options) {
        this.middlewareStack.use(getSerdePlugin(configuration, this.serialize, this.deserialize));
        var stack = clientStack.concat(this.middlewareStack);
        var logger = configuration.logger;
        var clientName = "CloudFormationClient";
        var commandName = "RegisterPublisherCommand";
        var handlerExecutionContext = {
            logger: logger,
            clientName: clientName,
            commandName: commandName,
            inputFilterSensitiveLog: RegisterPublisherInput.filterSensitiveLog,
            outputFilterSensitiveLog: RegisterPublisherOutput.filterSensitiveLog,
        };
        var requestHandler = configuration.requestHandler;
        return stack.resolve(function (request) {
            return requestHandler.handle(request.request, options || {});
        }, handlerExecutionContext);
    };
    RegisterPublisherCommand.prototype.serialize = function (input, context) {
        return serializeAws_queryRegisterPublisherCommand(input, context);
    };
    RegisterPublisherCommand.prototype.deserialize = function (output, context) {
        return deserializeAws_queryRegisterPublisherCommand(output, context);
    };
    return RegisterPublisherCommand;
}($Command));
export { RegisterPublisherCommand };
//# sourceMappingURL=RegisterPublisherCommand.js.map