import { __extends } from "tslib";
import { CreateSubnetCidrReservationRequest, CreateSubnetCidrReservationResult } from "../models/models_1";
import { deserializeAws_ec2CreateSubnetCidrReservationCommand, serializeAws_ec2CreateSubnetCidrReservationCommand, } from "../protocols/Aws_ec2";
import { getSerdePlugin } from "@aws-sdk/middleware-serde";
import { Command as $Command } from "@aws-sdk/smithy-client";
/**
 * <p>Creates a subnet CIDR reservation. For information about subnet CIDR reservations, see <a href="https://docs.aws.amazon.com/vpc/latest/userguide/subnet-cidr-reservation.html">Subnet CIDR reservations</a> in the <i>Amazon Virtual Private Cloud User Guide</i>.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { EC2Client, CreateSubnetCidrReservationCommand } from "@aws-sdk/client-ec2"; // ES Modules import
 * // const { EC2Client, CreateSubnetCidrReservationCommand } = require("@aws-sdk/client-ec2"); // CommonJS import
 * const client = new EC2Client(config);
 * const command = new CreateSubnetCidrReservationCommand(input);
 * const response = await client.send(command);
 * ```
 *
 * @see {@link CreateSubnetCidrReservationCommandInput} for command's `input` shape.
 * @see {@link CreateSubnetCidrReservationCommandOutput} for command's `response` shape.
 * @see {@link EC2ClientResolvedConfig | config} for command's `input` shape.
 *
 */
var CreateSubnetCidrReservationCommand = /** @class */ (function (_super) {
    __extends(CreateSubnetCidrReservationCommand, _super);
    // Start section: command_properties
    // End section: command_properties
    function CreateSubnetCidrReservationCommand(input) {
        var _this = 
        // Start section: command_constructor
        _super.call(this) || this;
        _this.input = input;
        return _this;
        // End section: command_constructor
    }
    /**
     * @internal
     */
    CreateSubnetCidrReservationCommand.prototype.resolveMiddleware = function (clientStack, configuration, options) {
        this.middlewareStack.use(getSerdePlugin(configuration, this.serialize, this.deserialize));
        var stack = clientStack.concat(this.middlewareStack);
        var logger = configuration.logger;
        var clientName = "EC2Client";
        var commandName = "CreateSubnetCidrReservationCommand";
        var handlerExecutionContext = {
            logger: logger,
            clientName: clientName,
            commandName: commandName,
            inputFilterSensitiveLog: CreateSubnetCidrReservationRequest.filterSensitiveLog,
            outputFilterSensitiveLog: CreateSubnetCidrReservationResult.filterSensitiveLog,
        };
        var requestHandler = configuration.requestHandler;
        return stack.resolve(function (request) {
            return requestHandler.handle(request.request, options || {});
        }, handlerExecutionContext);
    };
    CreateSubnetCidrReservationCommand.prototype.serialize = function (input, context) {
        return serializeAws_ec2CreateSubnetCidrReservationCommand(input, context);
    };
    CreateSubnetCidrReservationCommand.prototype.deserialize = function (output, context) {
        return deserializeAws_ec2CreateSubnetCidrReservationCommand(output, context);
    };
    return CreateSubnetCidrReservationCommand;
}($Command));
export { CreateSubnetCidrReservationCommand };
//# sourceMappingURL=CreateSubnetCidrReservationCommand.js.map