import { __extends } from "tslib";
import { DisassociateTrunkInterfaceRequest, DisassociateTrunkInterfaceResult } from "../models/models_4";
import { deserializeAws_ec2DisassociateTrunkInterfaceCommand, serializeAws_ec2DisassociateTrunkInterfaceCommand, } from "../protocols/Aws_ec2";
import { getSerdePlugin } from "@aws-sdk/middleware-serde";
import { Command as $Command } from "@aws-sdk/smithy-client";
/**
 * <p>Removes an association between a branch network interface with a trunk network interface.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { EC2Client, DisassociateTrunkInterfaceCommand } from "@aws-sdk/client-ec2"; // ES Modules import
 * // const { EC2Client, DisassociateTrunkInterfaceCommand } = require("@aws-sdk/client-ec2"); // CommonJS import
 * const client = new EC2Client(config);
 * const command = new DisassociateTrunkInterfaceCommand(input);
 * const response = await client.send(command);
 * ```
 *
 * @see {@link DisassociateTrunkInterfaceCommandInput} for command's `input` shape.
 * @see {@link DisassociateTrunkInterfaceCommandOutput} for command's `response` shape.
 * @see {@link EC2ClientResolvedConfig | config} for command's `input` shape.
 *
 */
var DisassociateTrunkInterfaceCommand = /** @class */ (function (_super) {
    __extends(DisassociateTrunkInterfaceCommand, _super);
    // Start section: command_properties
    // End section: command_properties
    function DisassociateTrunkInterfaceCommand(input) {
        var _this = 
        // Start section: command_constructor
        _super.call(this) || this;
        _this.input = input;
        return _this;
        // End section: command_constructor
    }
    /**
     * @internal
     */
    DisassociateTrunkInterfaceCommand.prototype.resolveMiddleware = function (clientStack, configuration, options) {
        this.middlewareStack.use(getSerdePlugin(configuration, this.serialize, this.deserialize));
        var stack = clientStack.concat(this.middlewareStack);
        var logger = configuration.logger;
        var clientName = "EC2Client";
        var commandName = "DisassociateTrunkInterfaceCommand";
        var handlerExecutionContext = {
            logger: logger,
            clientName: clientName,
            commandName: commandName,
            inputFilterSensitiveLog: DisassociateTrunkInterfaceRequest.filterSensitiveLog,
            outputFilterSensitiveLog: DisassociateTrunkInterfaceResult.filterSensitiveLog,
        };
        var requestHandler = configuration.requestHandler;
        return stack.resolve(function (request) {
            return requestHandler.handle(request.request, options || {});
        }, handlerExecutionContext);
    };
    DisassociateTrunkInterfaceCommand.prototype.serialize = function (input, context) {
        return serializeAws_ec2DisassociateTrunkInterfaceCommand(input, context);
    };
    DisassociateTrunkInterfaceCommand.prototype.deserialize = function (output, context) {
        return deserializeAws_ec2DisassociateTrunkInterfaceCommand(output, context);
    };
    return DisassociateTrunkInterfaceCommand;
}($Command));
export { DisassociateTrunkInterfaceCommand };
//# sourceMappingURL=DisassociateTrunkInterfaceCommand.js.map