import { __extends } from "tslib";
import { EnableImageDeprecationRequest, EnableImageDeprecationResult } from "../models/models_4";
import { deserializeAws_ec2EnableImageDeprecationCommand, serializeAws_ec2EnableImageDeprecationCommand, } from "../protocols/Aws_ec2";
import { getSerdePlugin } from "@aws-sdk/middleware-serde";
import { Command as $Command } from "@aws-sdk/smithy-client";
/**
 * <p>Enables deprecation of the specified AMI at the specified date and time.</p>
 *          <p>For more information, see <a href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ami-deprecate.html">Deprecate an AMI</a> in the <i>Amazon Elastic Compute Cloud User Guide</i>.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { EC2Client, EnableImageDeprecationCommand } from "@aws-sdk/client-ec2"; // ES Modules import
 * // const { EC2Client, EnableImageDeprecationCommand } = require("@aws-sdk/client-ec2"); // CommonJS import
 * const client = new EC2Client(config);
 * const command = new EnableImageDeprecationCommand(input);
 * const response = await client.send(command);
 * ```
 *
 * @see {@link EnableImageDeprecationCommandInput} for command's `input` shape.
 * @see {@link EnableImageDeprecationCommandOutput} for command's `response` shape.
 * @see {@link EC2ClientResolvedConfig | config} for command's `input` shape.
 *
 */
var EnableImageDeprecationCommand = /** @class */ (function (_super) {
    __extends(EnableImageDeprecationCommand, _super);
    // Start section: command_properties
    // End section: command_properties
    function EnableImageDeprecationCommand(input) {
        var _this = 
        // Start section: command_constructor
        _super.call(this) || this;
        _this.input = input;
        return _this;
        // End section: command_constructor
    }
    /**
     * @internal
     */
    EnableImageDeprecationCommand.prototype.resolveMiddleware = function (clientStack, configuration, options) {
        this.middlewareStack.use(getSerdePlugin(configuration, this.serialize, this.deserialize));
        var stack = clientStack.concat(this.middlewareStack);
        var logger = configuration.logger;
        var clientName = "EC2Client";
        var commandName = "EnableImageDeprecationCommand";
        var handlerExecutionContext = {
            logger: logger,
            clientName: clientName,
            commandName: commandName,
            inputFilterSensitiveLog: EnableImageDeprecationRequest.filterSensitiveLog,
            outputFilterSensitiveLog: EnableImageDeprecationResult.filterSensitiveLog,
        };
        var requestHandler = configuration.requestHandler;
        return stack.resolve(function (request) {
            return requestHandler.handle(request.request, options || {});
        }, handlerExecutionContext);
    };
    EnableImageDeprecationCommand.prototype.serialize = function (input, context) {
        return serializeAws_ec2EnableImageDeprecationCommand(input, context);
    };
    EnableImageDeprecationCommand.prototype.deserialize = function (output, context) {
        return deserializeAws_ec2EnableImageDeprecationCommand(output, context);
    };
    return EnableImageDeprecationCommand;
}($Command));
export { EnableImageDeprecationCommand };
//# sourceMappingURL=EnableImageDeprecationCommand.js.map